@@ -9,6 +9,7 @@ from typing import (
     Tuple,
     Union)
 from copy import deepcopy
+import warnings
 
 import numpy as np
 import SimpleITK as sitk
@@ -16,6 +17,7 @@ import SimpleITK as sitk
 from pyradise.data import (
     Subject,
     SegmentationImage,
+    IntensityImage,
     Modality,
     Organ,
     Annotator,
@@ -595,7 +597,8 @@ class InferenceFilter(Filter):
 
     def execute_inverse(self,
                         subject: Subject,
-                        transform_info: TransformInfo
+                        transform_info: TransformInfo,
+                        target_image: Optional[Union[SegmentationImage, IntensityImage]] = None
                         ) -> Subject:
         """Return the provided :class:`~pyradise.data.subject.Subject` instance without any processing because
         the inference of a DL-model is typically not invertible.
@@ -603,8 +606,17 @@ class InferenceFilter(Filter):
         Args:
             subject (Subject): The :class:`~pyradise.data.subject.Subject` instance to be returned.
             transform_info (TransformInfo): The transform information.
+            target_image (Optional[Union[SegmentationImage, IntensityImage]]): The target image to which the inverse
+             transformation should be applied. If None, the inverse transformation is applied to all images (default:
+             None).
 
         Returns:
             Subject: The provided :class:`~pyradise.data.subject.Subject` instance.
         """
+
+        # potentially warn the user that the operation is not invertible
+        if self.warn_on_non_invertible:
+            warnings.warn(f'The {self.__class__.__name__} filter is called but is not invertible. '
+                          'The provided subject is returned without modification.')
+
         return subject
